@@ -13,20 +13,28 @@
 #' @slot boot The results of `resilp` from R bootstrap samples.
 #' @slot origine The original `silp` estimation.
 #' @slot time_resilp The operation time for `resilp` (in seconds).
+#' @slot tech detail of `resilp` operation
 #' @exportClass Silp
 #' @exportMethod summary
 
+# summary(refit)
 
 setClass("Silp", slots = list(raw_model = "character", rapi_model = "character", 
                               time = "numeric", npd = "logical", raw_data = "data.frame", fa = "lavaan", 
                               reliability = "data.frame", composite_data = "data.frame", pa = "lavaan",
                               boot = "data.frame", origine = "data.frame",
-                              time_resilp = "numeric"))
+                              time_resilp = "numeric", tech = "list") )
 
 setMethod("summary", signature("Silp"),function(object, method = "Bootstrap", sig_level = 0.05){ 
   print(summary(object@pa)) 
 
   if(length(object@time_resilp) != 0){
+    cat("\n")
+
+    cat("Bootstrap summary:", object@tech$R, "target samples,", 
+        object@tech$`resample count` - object@tech$R, "additional resampling attempts due to failed estimations.\n")
+
+    
     b_est = object@boot[,-c(1:11)]
     result = lavaan::partable(object@pa)[,2:12]
     result["estimated"] = rowMeans(b_est[,1:ncol(b_est)])
